@@ -58,6 +58,7 @@ class AltosIdler {
 	static final int	idle_sensor_emini3 = 112;
 	static final int	idle_sensor_etimer2 = 113;
 	static final int	idle_sensor_emega3 = 114;
+	static final int	idle_sensor_tgps4 = 115;
 
 	public void provide_data(AltosDataListener listener, AltosLink link) throws InterruptedException, TimeoutException, AltosUnknownProduct {
 		for (int idler : idlers) {
@@ -134,6 +135,9 @@ class AltosIdler {
 			case idle_sensor_tgps3:
 				AltosSensorTGPS3.provide_data(listener, link);
 				break;
+			case idle_sensor_tgps4:
+				AltosSensorTGPS4.provide_data(listener, link);
+				break;
 			case idle_sensor_tmini3:
 				AltosSensorTMini3.provide_data(listener, link);
 				break;
@@ -249,6 +253,12 @@ public class AltosIdleFetch implements AltosDataProvider {
 			       AltosIdler.idle_ms5607,
 			       AltosIdler.idle_imu, AltosIdler.idle_mag,
 			       AltosIdler.idle_sensor_mega),
+		new AltosIdler("TeleMega-v7",
+			       AltosIdler.idle_gps,
+			       AltosIdler.idle_adxl375,
+			       AltosIdler.idle_ms5607,
+			       AltosIdler.idle_imu, AltosIdler.idle_mag,
+			       AltosIdler.idle_sensor_mega),
 		new AltosIdler("EasyMega-v1",
 			       AltosIdler.idle_mma655x,
 			       AltosIdler.idle_ms5607,
@@ -274,6 +284,9 @@ public class AltosIdleFetch implements AltosDataProvider {
 		new AltosIdler("TeleGPS-v3",
 			       AltosIdler.idle_gps,
 			       AltosIdler.idle_sensor_tgps3),
+		new AltosIdler("TeleGPS-v4",
+			       AltosIdler.idle_gps,
+			       AltosIdler.idle_sensor_tgps4),
 		new AltosIdler("EasyTimer-v1",
 			       AltosIdler.idle_imu_et_v1,
 			       AltosIdler.idle_sensor_easytimer1),
