@@ -105,20 +105,6 @@ public class AltosTelemetryMegaSensor extends AltosTelemetryStandard {
 		return gyro_z();
 	}
 
-	public static int mag_across_axis(int imu_type) {
-		switch (imu_type) {
-		case AltosIMU.imu_type_telemega_v1_v2:
-		case AltosIMU.imu_type_telemega_v3:
-		case AltosIMU.imu_type_easymega_v1:
-			return AltosIMU.imu_axis_x;
-		case AltosIMU.imu_type_telemega_v4:
-		case AltosIMU.imu_type_easymega_v2:
-			return AltosIMU.imu_axis_y;
-		default:
-			return AltosLib.MISSING;
-		}
-	}
-
 	private int mag_across(int imu_type) {
 		switch (imu_type) {
 		case AltosIMU.imu_type_telemega_v1_v2:
@@ -133,20 +119,6 @@ public class AltosTelemetryMegaSensor extends AltosTelemetryStandard {
 		}
 	}
 
-	public static int mag_along_axis(int imu_type) {
-		switch (imu_type) {
-		case AltosIMU.imu_type_telemega_v1_v2:
-		case AltosIMU.imu_type_telemega_v3:
-		case AltosIMU.imu_type_easymega_v1:
-			return AltosIMU.imu_axis_y;
-		case AltosIMU.imu_type_easymega_v2:
-		case AltosIMU.imu_type_telemega_v4:
-			return AltosIMU.imu_axis_x;
-		default:
-			return AltosLib.MISSING;
-		}
-	}
-
 	private int mag_along(int imu_type) {
 		switch (imu_type) {
 		case AltosIMU.imu_type_telemega_v1_v2:
@@ -161,10 +133,6 @@ public class AltosTelemetryMegaSensor extends AltosTelemetryStandard {
 		}
 	}
 
-	public static int mag_through_axis(int imu_type) {
-		return AltosIMU.imu_axis_z;
-	}
-
 	private int mag_through(int imu_type) {
 		return mag_z();
 	}
