@@ -354,6 +354,8 @@ main (int argc, char **argv)
 			len = 2;
 			break;
 		case AO_LOG_FORMAT_TELEMEGA_4:
+		case AO_LOG_FORMAT_TELEMEGA_5:
+		case AO_LOG_FORMAT_TELEMEGA_6:
 			len = 32;
 			max_adc= 4095;
 			adc_ref = 3.3;
@@ -375,6 +377,11 @@ main (int argc, char **argv)
 		}
 		if (arg_len)
 			len = arg_len;
+		if (len == 0) {
+			fprintf(stderr, "Unknown eeprom format %d and no specified length\n",
+				eeprom->log_format);
+			exit(1);
+		}
 		if (verbose)
 			printf("config major %d minor %d log format %d total %u len %d\n",
 			       eeprom->config.major,
@@ -421,6 +428,8 @@ main (int argc, char **argv)
 				case AO_LOG_FORMAT_TELEMEGA_3:
 				case AO_LOG_FORMAT_EASYMEGA_2:
 				case AO_LOG_FORMAT_TELEMEGA_4:
+				case AO_LOG_FORMAT_TELEMEGA_5:
+				case AO_LOG_FORMAT_TELEMEGA_6:
 					log_mega = (struct ao_log_mega *) &eeprom->data[pos];
 					switch (log_mega->type) {
 					case AO_LOG_FLIGHT:
