@@ -18,7 +18,7 @@
 
 #include <ao.h>
 
-static int	ao_watchdog_enabled = TRUE;
+static int	ao_watchdog_enabled = true;
 
 static void
 ao_watchdog(void)
@@ -28,9 +28,9 @@ ao_watchdog(void)
 			ao_sleep(&ao_watchdog_enabled);
 		while (ao_watchdog_enabled) {
 			ao_delay(AO_WATCHDOG_INTERVAL);
-			ao_gpio_set(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, AO_WATCHDOG_PIN, 1);
+			ao_gpio_set(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, 1);
 			ao_delay(1);
-			ao_gpio_set(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, AO_WATCHDOG_PIN, 0);
+			ao_gpio_set(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, 0);
 		}
 	}
 }
@@ -38,15 +38,15 @@ ao_watchdog(void)
 static void
 ao_watchdog_set(void)
 {
-	ao_cmd_hex();
+	uint32_t r = ao_cmd_hex();
 	if (ao_cmd_status == ao_cmd_success) {
-		ao_watchdog_enabled = ao_cmd_lex_i != 0;
+		ao_watchdog_enabled = r != 0;
 		ao_wakeup(&ao_watchdog_enabled);
 	}
 }
 	
 
-static __code struct ao_cmds ao_watchdog_cmds[] = {
+static const struct ao_cmds ao_watchdog_cmds[] = {
 	{ ao_watchdog_set,	"Q <0 off, 1 on>\0Enable or disable watchdog timer" },
 	{ 0,			NULL },
 };
@@ -56,7 +56,7 @@ static struct ao_task watchdog_task;
 void
 ao_watchdog_init(void)
 {
-	ao_enable_output(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, AO_WATCHDOG, 0);
+	ao_enable_output(AO_WATCHDOG_PORT, AO_WATCHDOG_BIT, 0);
 	ao_cmd_register(&ao_watchdog_cmds[0]);
 	ao_add_task(&watchdog_task, ao_watchdog, "watchdog");
 }
