@@ -300,28 +300,28 @@ struct ao_adc {
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * bmx160
+ * mpu9250
  */
 
-#define HAS_BMX160		1
-#define AO_BMX160_INT_PORT	(&stm_gpioc)
-#define AO_BMX160_INT_PIN	15
-#define AO_BMX160_SPI_BUS	(AO_SPI_2_PB13_PB14_PB15 | AO_SPI_MODE_0)
-#define AO_BMX160_SPI_CS_PORT	(&stm_gpioc)
-#define AO_BMX160_SPI_CS_PIN	13
+#define HAS_MPU9250		1
+#define AO_MPU9250_INT_PORT	(&stm_gpioc)
+#define AO_MPU9250_INT_PIN	15
+#define AO_MPU9250_SPI_BUS	(AO_SPI_2_PB13_PB14_PB15 | AO_SPI_MODE_0)
+#define AO_MPU9250_SPI_CS_PORT	(&stm_gpioc)
+#define AO_MPU9250_SPI_CS_PIN	13
 #define HAS_IMU			1
 
-#define ao_data_along(packet)	((packet)->bmx160.acc_x)
-#define ao_data_across(packet)	(-(packet)->bmx160.acc_y)
-#define ao_data_through(packet)	((packet)->bmx160.acc_z)
+#define ao_data_along(packet)	((packet)->mpu9250.accel_x)
+#define ao_data_across(packet)	(-(packet)->mpu9250.accel_y)
+#define ao_data_through(packet)	((packet)->mpu9250.accel_z)
 
-#define ao_data_roll(packet)	((packet)->bmx160.gyr_x)
-#define ao_data_pitch(packet)	(-(packet)->bmx160.gyr_y)
-#define ao_data_yaw(packet)	((packet)->bmx160.gyr_z)
+#define ao_data_roll(packet)	((packet)->mpu9250.gyro_x)
+#define ao_data_pitch(packet)	(-(packet)->mpu9250.gyro_y)
+#define ao_data_yaw(packet)	((packet)->mpu9250.gyro_z)
 
-#define ao_data_mag_along(packet)	((packet)->bmx160.mag_x)
-#define ao_data_mag_across(packet)	(-(packet)->bmx160.mag_y)
-#define ao_data_mag_through(packet)	((packet)->bmx160.mag_z)
+#define ao_data_mag_along(packet)	((packet)->mpu9250.mag_y)
+#define ao_data_mag_across(packet)	(-(packet)->mpu9250.mag_x)
+#define ao_data_mag_through(packet)	((packet)->mpu9250.mag_z)
 
 /* ADXL375 */
 
