@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013 Keith Packard <keithp@keithp.com>
+ * Copyright © 2017 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,76 +19,34 @@
 #define HAS_BEEP		1
 #define HAS_BATTERY_REPORT	1
 
-#define AO_STACK_SIZE		352
-#define SLEEP_HASH_SIZE		3
-#define AO_NUM_TASKS		6
+#define AO_STACK_SIZE	432
 
 #define IS_FLASH_LOADER	0
 
-/* Crystal on the board */
-#define AO_LPC_CLKIN	12000000
+/* 48MHz clock based on 16MHz reference */
+//#define AO_HSI48	1
+#define AO_HSE			16000000
+#define AO_RCC_CFGR_PLLMUL	STM_RCC_CFGR_PLLMUL_3
+#define AO_RCC_CFGR2_PLLDIV	STM_RCC_CFGR2_PREDIV_1
+#define AO_PLLMUL		3
+#define AO_PLLDIV		1
 
-/* Main clock frequency. 48MHz for USB so we don't use the USB PLL */
-#define AO_LPC_CLKOUT	48000000
+/* HCLK = 48MHz */
+#define AO_AHB_PRESCALER	1
+#define AO_RCC_CFGR_HPRE_DIV	STM_RCC_CFGR_HPRE_DIV_1
 
-/* System clock frequency */
-#define AO_LPC_SYSCLK	24000000
+/* APB = 40MHz */
+#define AO_APB_PRESCALER	1
+#define AO_RCC_CFGR_PPRE_DIV	STM_RCC_CFGR_PPRE_DIV_1
 
-/* Beeper is on pio0_14 ct32b1_mat1 */
-#define BEEPER_PORT	0
-#define BEEPER_PIN	14
-#define BEEPER_TIMER	1
-#define BEEPER_OUTPUT	1
+#define HAS_USB			1
+#define AO_USB_DIRECTIO		0
+#define AO_PA11_PA12_RMP	1
+#define AO_USB_FORCE_IDLE	1
 
-#define HAS_USB		1
+#define AO_LOG_FORMAT		AO_LOG_FORMAT_EASYMINI2
 
-#define HAS_USB_CONNECT	0
-#define HAS_USB_VBUS	0
-#define HAS_USB_PULLUP	1
-#define AO_USB_PULLUP_PORT	0
-#define AO_USB_PULLUP_PIN	20
-
-#define PACKET_HAS_SLAVE	0
-
-#define AO_LOG_FORMAT		AO_LOG_FORMAT_EASYMINI1
-
-/* USART */
-
-#define HAS_SERIAL		0
-#define USE_SERIAL_0_STDIN	1
-#define SERIAL_0_18_19		1
-#define SERIAL_0_14_15		0
-#define SERIAL_0_17_18		0
-#define SERIAL_0_26_27		0
-
-/* SPI */
-
-#define HAS_SPI_0		1
-#define SPI_SCK0_P0_6		1
-#define HAS_SPI_1		1
-#define SPI_SCK1_P1_15		1
-#define SPI_MISO1_P0_22		1
-#define SPI_MOSI1_P0_21		1
-
-/* M25 */
-
-#define M25_MAX_CHIPS		1
-#define AO_M25_SPI_CS_PORT	0
-#define AO_M25_SPI_CS_MASK	(1 << 23)
-#define AO_M25_SPI_BUS		1
-
-/* MS5607 */
-
-#define HAS_MS5607		1
-#define HAS_MS5611		0
-#define AO_MS5607_PRIVATE_PINS	0
-#define AO_MS5607_CS_PORT	0
-#define AO_MS5607_CS_PIN	7
-#define AO_MS5607_CS_MASK	(1 << AO_MS5607_CS_PIN)
-#define AO_MS5607_MISO_PORT	0
-#define AO_MS5607_MISO_PIN	8
-#define AO_MS5607_MISO_MASK	(1 << AO_MS5607_MISO_PIN)
-#define AO_MS5607_SPI_INDEX	0
+#define HAS_BOOT_RADIO		0
 
 #define HAS_ACCEL		0
 #define HAS_GPS			0
@@ -101,9 +59,42 @@
 #define USE_INTERNAL_FLASH	0
 #define HAS_IGNITE		1
 #define HAS_IGNITE_REPORT	1
-#define SLEEP_HASH_SIZE		3
 
-#define AO_DATA_RING		16
+/* Beeper is on Tim3 CH4 */
+#define BEEPER_TIMER		3
+#define BEEPER_CHANNEL		4
+#define BEEPER_PORT		(&stm_gpiob)
+#define BEEPER_PIN		1
+#define BEEPER_AFR		STM_AFR_AF1
+
+/* SPI */
+
+#define HAS_SPI_1		1
+#define SPI_1_PA5_PA6_PA7	1
+#define SPI_1_PB3_PB4_PB5	1
+#define SPI_1_OSPEEDR		STM_OSPEEDR_MEDIUM
+
+/* M25 */
+
+#define M25_MAX_CHIPS		1
+#define AO_M25_SPI_CS_PORT	(&stm_gpioa)
+#define AO_M25_SPI_CS_MASK	(1 << 15)
+#define AO_M25_SPI_BUS		AO_SPI_1_PB3_PB4_PB5
+
+/* MS5607 */
+
+#define HAS_MS5607		1
+#define HAS_MS5611		0
+#define AO_MS5607_PRIVATE_PINS	1
+#define AO_MS5607_CS_PORT	(&stm_gpioa)
+#define AO_MS5607_CS_PIN	4
+#define AO_MS5607_CS_MASK	(1 << AO_MS5607_CS_PIN)
+#define AO_MS5607_MISO_PORT	(&stm_gpioa)
+#define AO_MS5607_MISO_PIN	6
+#define AO_MS5607_MISO_MASK	(1 << AO_MS5607_MISO_PIN)
+#define AO_MS5607_SPI_INDEX	AO_SPI_1_PA5_PA6_PA7
+
+#define AO_DATA_RING		64
 
 /*
  * ADC
@@ -111,15 +102,23 @@
 
 #define HAS_ADC			1
 
+#define AO_ADC_PIN0_PORT	(&stm_gpioa)	/* sense_m */
+#define AO_ADC_PIN0_PIN		0
+#define AO_ADC_PIN0_CH		0
+#define AO_ADC_PIN1_PORT	(&stm_gpioa)	/* sense_a */
+#define AO_ADC_PIN1_PIN		1
+#define AO_ADC_PIN1_CH		1
+#define AO_ADC_PIN2_PORT	(&stm_gpioa)	/* v_batt */
+#define AO_ADC_PIN2_PIN		2
+#define AO_ADC_PIN2_CH		2
+
+#define AO_ADC_RCC_AHBENR	((1 << STM_RCC_AHBENR_IOPAEN))
+
 #define AO_NUM_ADC		3
 
-#define AO_ADC_0		1
-#define AO_ADC_1		1
-#define AO_ADC_2		1
-
 struct ao_adc {
-	int16_t		sense_a;
 	int16_t		sense_m;
+	int16_t		sense_a;
 	int16_t		v_batt;
 };
 
@@ -130,11 +129,11 @@ struct ao_adc {
 #define AO_IGNITER_CLOSED	400
 #define AO_IGNITER_OPEN		60
 
-#define AO_IGNITER_DROGUE_PORT	0
-#define AO_IGNITER_DROGUE_PIN	2
+#define AO_IGNITER_DROGUE_PORT	(&stm_gpioa)
+#define AO_IGNITER_DROGUE_PIN	3
 
-#define AO_IGNITER_MAIN_PORT	0
-#define AO_IGNITER_MAIN_PIN	3
+#define AO_IGNITER_MAIN_PORT	(&stm_gpiob)
+#define AO_IGNITER_MAIN_PIN	7
 
 #define AO_SENSE_DROGUE(p)	((p)->adc.sense_a)
 #define AO_SENSE_MAIN(p)	((p)->adc.sense_m)
