@@ -34,7 +34,7 @@ struct ao_companion_command {
 	int16_t		accel;
 	int16_t		speed;
 	int16_t		height;
-	int16_t		motor_number;
+	uint16_t	motor_number;
 };
 
 struct ao_companion_setup {
