@@ -42,12 +42,6 @@ ao_led_set(AO_PORT_TYPE colors)
 	ao_led_on(on);
 }
 
-void
-ao_led_toggle(AO_PORT_TYPE colors)
-{
-	lpc_gpio.pin[LED_PORT] ^= colors;
-}
-
 void
 ao_led_for(AO_PORT_TYPE colors, AO_TICK_TYPE ticks) 
 {
