@@ -13,35 +13,21 @@
  */
 
 #include <ao.h>
-#include <ao_lisp.h>
-#include <ao_beep.h>
+#include <ao_bmi088.h>
 
-static void lisp_cmd() {
-	ao_lisp_read_eval_print();
-}
+uint8_t	ao_sensor_errors;
 
-static void beep() {
-	ao_beep_for(AO_BEEP_MID, AO_MS_TO_TICKS(200));
-}
-
-static const struct ao_cmds blink_cmds[] = {
-	{ lisp_cmd,	"l\0Run lisp interpreter" },
-	{ beep,		"b\0Beep" },
-	{ 0, 0 }
-};
-
-void main(void)
+int main(void)
 {
-	ao_led_init(LEDS_AVAILABLE);
+	ao_led_init();
 	ao_clock_init();
 	ao_task_init();
 	ao_timer_init();
 	ao_dma_init();
 	ao_usb_init();
-	ao_serial_init();
-	ao_beep_init();
+	ao_spi_init();
+	ao_bmi088_init();
 	ao_cmd_init();
-	ao_cmd_register(blink_cmds);
 	ao_start_scheduler();
 }
 
