@@ -212,18 +212,6 @@ extern struct stm_flash	stm_flash;
 #define  STM_FLASH_ACR_LATENCY_0		0
 #define  STM_FLASH_ACR_LATENCY_1		1
 
-#define STM_FLASH_PECR_OBL_LAUNCH	18
-#define STM_FLASH_PECR_ERRIE		17
-#define STM_FLASH_PECR_EOPIE		16
-#define STM_FLASH_PECR_FPRG		10
-#define STM_FLASH_PECR_ERASE		9
-#define STM_FLASH_PECR_FTDW		8
-#define STM_FLASH_PECR_DATA		4
-#define STM_FLASH_PECR_PROG		3
-#define STM_FLASH_PECR_OPTLOCK		2
-#define STM_FLASH_PECR_PRGLOCK		1
-#define STM_FLASH_PECR_PELOCK		0
-
 #define STM_FLASH_SR_EOP		5
 #define STM_FLASH_SR_WRPRTERR		4
 #define STM_FLASH_SR_PGERR		2
