@@ -43,8 +43,8 @@ main(void)
 
 	ao_task_init();
 	ao_serial_init();
-	ao_led_init(LEDS_AVAILABLE);
-	ao_led_on(AO_LED_RED);
+	ao_led_init();
+	ao_led_on(LEDS_AVAILABLE);
 	ao_timer_init();
 
 	ao_spi_init();
@@ -77,7 +77,7 @@ main(void)
 	ao_gps_report_metrum_init();
 	ao_telemetry_init();
 	ao_radio_init();
-	ao_packet_slave_init(FALSE);
+	ao_packet_slave_init(false);
 	ao_companion_init();
 
 	ao_config_init();
@@ -87,7 +87,8 @@ main(void)
 #if HAS_SAMPLE_PROFILE
 	ao_sample_profile_init();
 #endif
-	
+	ao_led_off(LEDS_AVAILABLE);
+
 	ao_start_scheduler();
 	return 0;
 }
