@@ -19,9 +19,14 @@
 #include <ao.h>
 #include <ao_exti.h>
 #include <ao_packet.h>
+#include <ao_eeprom.h>
+#include <ao_profile.h>
+#include <ao_btm.h>
+#include <ao_lco_cmd.h>
 #include <ao_send_packet.h>
-#include <ao_usb.h>
-#include <ao_rn4678.h>
+#if HAS_SAMPLE_PROFILE
+#include <ao_sample_profile.h>
+#endif
 
 int
 main(void)
@@ -38,16 +43,18 @@ main(void)
 	ao_exti_init();
 
 	ao_adc_init();
+	ao_btm_init();
 	ao_cmd_init();
-	ao_send_packet_init();
+
+	ao_lco_cmd_init();
+
+	ao_eeprom_init();
 
 	ao_usb_init();
-	ao_serial_init();
-
 	ao_radio_init();
 	ao_packet_master_init();
 	ao_monitor_init();
-	ao_rn4678_init();
+	ao_send_packet_init();
 
 	ao_config_init();
 
