@@ -1,5 +1,5 @@
 /*
- * Copyright © 2023 Keith Packard <keithp@keithp.com>
+ * Copyright © 2013 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,17 +19,17 @@
 #ifndef _AO_PINS_H_
 #define _AO_PINS_H_
 
-#include <ao_flash_lpc_pins.h>
+/* External crystal at 8MHz */
+#define AO_HSE		8000000
 
-/* Debug pin 6, rx_ext */
-#define AO_BOOT_PIN		1
-#define AO_BOOT_APPLICATION_GPIO	1
-#define AO_BOOT_APPLICATION_PIN		16
+#include <ao_flash_stm_pins.h>
+
+/* Telemetry TX pin PB6 */
+
+#define AO_BOOT_PIN			1
+#define AO_BOOT_APPLICATION_GPIO	stm_gpiob
+#define AO_BOOT_APPLICATION_PIN		6
 #define AO_BOOT_APPLICATION_VALUE	1
 #define AO_BOOT_APPLICATION_MODE	AO_EXTI_MODE_PULL_UP
 
-#define HAS_USB_PULLUP		1
-#define AO_USB_PULLUP_PORT	1
-#define AO_USB_PULLUP_PIN	23
-
 #endif /* _AO_PINS_H_ */
