@@ -1,5 +1,5 @@
 /*
- * Copyright © 2011 Keith Packard <keithp@keithp.com>
+ * Copyright © 2021 Keith Packard <keithp@keithp.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,15 +17,16 @@
  */
 
 #include <ao.h>
-#include <ao_hmc5883.h>
 #include <ao_mpu6000.h>
-#include <ao_mma655x.h>
+#include <ao_mmc5983.h>
+#include <ao_adxl375.h>
 #include <ao_log.h>
 #include <ao_exti.h>
 #include <ao_packet.h>
 #include <ao_companion.h>
 #include <ao_profile.h>
 #include <ao_eeprom.h>
+#include <ao_i2c_bit.h>
 #if HAS_SAMPLE_PROFILE
 #include <ao_sample_profile.h>
 #endif
@@ -33,12 +34,13 @@
 #if HAS_STACK_GUARD
 #include <ao_mpu.h>
 #endif
+#include <ao_pwm.h>
 
 int
 main(void)
 {
 	ao_clock_init();
-	
+
 #if HAS_STACK_GUARD
 	ao_mpu_init();
 #endif
@@ -49,8 +51,10 @@ main(void)
 	ao_led_on(LEDS_AVAILABLE);
 	ao_timer_init();
 
-	ao_i2c_init();
 	ao_spi_init();
+#ifdef MMC5983_I2C
+	ao_i2c_bit_init();
+#endif
 	ao_dma_init();
 	ao_exti_init();
 
@@ -60,22 +64,14 @@ main(void)
 #endif
 	ao_cmd_init();
 
-#if HAS_MS5607
 	ao_ms5607_init();
-#endif
-#if HAS_HMC5883
-	ao_hmc5883_init();
-#endif
-#if HAS_MPU6000
 	ao_mpu6000_init();
-#endif
-#if HAS_MMA655X
-	ao_mma655x_init();
-#endif
+	ao_mmc5983_init();
+	ao_adxl375_init();
 
 	ao_eeprom_init();
 	ao_storage_init();
-	
+
 	ao_flight_init();
 	ao_log_init();
 	ao_report_init();
@@ -97,8 +93,11 @@ main(void)
 #if HAS_SAMPLE_PROFILE
 	ao_sample_profile_init();
 #endif
-	
+
+	ao_pwm_init();
+
 	ao_led_off(LEDS_AVAILABLE);
+
 	ao_start_scheduler();
 	return 0;
 }
