@@ -20,12 +20,12 @@
 #define _AO_PINS_H_
 
 
-/* 8MHz High speed external crystal */
-#define AO_HSE			8000000
+/* 16MHz High speed external crystal */
+#define AO_HSE			16000000
 
 /* PLLVCO = 96MHz (so that USB will work) */
-#define AO_PLLMUL		12
-#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_12)
+#define AO_PLLMUL		6
+#define AO_RCC_CFGR_PLLMUL	(STM_RCC_CFGR_PLLMUL_6)
 
 /* SYSCLK = 32MHz (no need to go faster than CPU) */
 #define AO_PLLDIV		3
@@ -43,33 +43,56 @@
 #define AO_APB2_PRESCALER	2
 #define AO_RCC_CFGR_PPRE2_DIV	STM_RCC_CFGR_PPRE2_DIV_2
 
+#define HAS_GPS_MOSAIC		1
+
+#if HAS_GPS_MOSAIC
+
+/* Companion cs_companion0(pin 6) = TX cs_companion1 (pin 5) = RX */
+
+#define HAS_SERIAL_1		1
+#define USE_SERIAL_1_STDIN	0
+#define SERIAL_1_PB6_PB7	1
+#define SERIAL_1_PA9_PA10	0
+
+#define ao_mosaic_getchar	ao_serial1_getchar
+#define ao_mosaic_putchar	ao_serial1_putchar
+#define ao_mosaic_set_speed	ao_serial1_set_speed
+#define _ao_mosaic_sleep_for	_ao_serial1_sleep_for
+#define _ao_mosaic_pollchar	_ao_serial1_pollchar
+#define ao_mosaic_fifo		(ao_stm_usart1.rx_fifo)
+
+#else
 #define HAS_SERIAL_1		0
 #define USE_SERIAL_1_STDIN	0
 #define SERIAL_1_PB6_PB7	0
 #define SERIAL_1_PA9_PA10	0
+#endif
 
-#define HAS_SERIAL_2		0
+#define HAS_SERIAL_2		1
 #define USE_SERIAL_2_STDIN	0
-#define SERIAL_2_PA2_PA3	0
+#define SERIAL_2_PA2_PA3	1
 #define SERIAL_2_PD5_PD6	0
+#define USE_SERIAL_2_FLOW	0
+#define USE_SERIAL_2_SW_FLOW	0
 
-#define HAS_SERIAL_3		1
+#define HAS_SERIAL_3		0
 #define USE_SERIAL_3_STDIN	0
 #define SERIAL_3_PB10_PB11	0
-#define SERIAL_3_PC10_PC11	1
+#define SERIAL_3_PC10_PC11	0
 #define SERIAL_3_PD8_PD9	0
 
-#define ao_gps_getchar		ao_serial3_getchar
-#define ao_gps_putchar		ao_serial3_putchar
-#define ao_gps_set_speed	ao_serial3_set_speed
-#define ao_gps_fifo		(ao_stm_usart3.rx_fifo)
+#define ao_gps_getchar		ao_serial2_getchar
+#define ao_gps_putchar		ao_serial2_putchar
+#define ao_gps_set_speed	ao_serial2_set_speed
+#define ao_gps_fifo		(ao_stm_usart2.rx_fifo)
 
 #define AO_CONFIG_DEFAULT_FLIGHT_LOG_MAX	(1024 * 1024)
 #define AO_CONFIG_MAX_SIZE			1024
 #define LOG_ERASE_MARK				0x55
 #define LOG_MAX_ERASE				128
-#define AO_LOG_FORMAT				AO_LOG_FORMAT_TELEMEGA_4
+#define AO_LOG_FORMAT				AO_LOG_FORMAT_TELEMEGA_6
 #define AO_TELEMETRY_MEGA_DATA AO_TELEMETRY_MEGA_DATA_15V
+#define AO_LOG_NORMALIZED			1
 
 #define HAS_EEPROM		1
 #define USE_INTERNAL_FLASH	0
@@ -78,9 +101,9 @@
 #define HAS_USB			1
 #define HAS_BEEP		1
 #define BEEPER_TIMER		3
-#define BEEPER_CHANNEL		1
-#define BEEPER_PORT		(&stm_gpioc)
-#define BEEPER_PIN		6
+#define BEEPER_CHANNEL		2
+#define BEEPER_PORT		(&stm_gpioe)
+#define BEEPER_PIN		4
 #define HAS_BATTERY_REPORT	1
 #define HAS_RADIO		1
 #define HAS_TELEMETRY		1
@@ -90,12 +113,16 @@
 #define HAS_SPI_1		1
 #define SPI_1_PA5_PA6_PA7	1	/* Barometer */
 #define SPI_1_PB3_PB4_PB5	1	/* Accelerometer */
-#define SPI_1_PE13_PE14_PE15	1	/* IMU */
+#define SPI_1_PE13_PE14_PE15	1	/* MPU6000 */
 #define SPI_1_OSPEEDR		STM_OSPEEDR_10MHz
 
+//#define MMC5983_I2C		1
+
 #define HAS_SPI_2		1
 #define SPI_2_PB13_PB14_PB15	1	/* Flash, Companion */
-#define SPI_2_PD1_PD3_PD4	0
+#ifndef MMC5983_I2C
+#define SPI_2_PD1_PD3_PD4	1	/* MMC5983 */
+#endif
 #define SPI_2_OSPEEDR		STM_OSPEEDR_10MHz
 
 #define HAS_I2C_1		0
@@ -146,12 +173,12 @@
 #define AO_PYRO_PIN_1	7
 
 /* Pyro C */
-#define AO_PYRO_PORT_2	(&stm_gpiod)
-#define AO_PYRO_PIN_2	5
+#define AO_PYRO_PORT_2	(&stm_gpioe)
+#define AO_PYRO_PIN_2	3
 
 /* Pyro D */
 #define AO_PYRO_PORT_3	(&stm_gpioe)
-#define AO_PYRO_PIN_3	4
+#define AO_PYRO_PIN_3	2
 
 /* Drogue */
 #define AO_IGNITER_DROGUE_PORT	(&stm_gpioe)
@@ -192,13 +219,13 @@ struct ao_adc {
 #define AO_ADC_SENSE_B_PORT	(&stm_gpioa)
 #define AO_ADC_SENSE_B_PIN	1
 
-#define AO_ADC_SENSE_C		2
-#define AO_ADC_SENSE_C_PORT	(&stm_gpioa)
-#define AO_ADC_SENSE_C_PIN	2
+#define AO_ADC_SENSE_C		24
+#define AO_ADC_SENSE_C_PORT	(&stm_gpioe)
+#define AO_ADC_SENSE_C_PIN	9
 
-#define AO_ADC_SENSE_D		3
-#define AO_ADC_SENSE_D_PORT	(&stm_gpioa)
-#define AO_ADC_SENSE_D_PIN	3
+#define AO_ADC_SENSE_D		25
+#define AO_ADC_SENSE_D_PORT	(&stm_gpioe)
+#define AO_ADC_SENSE_D_PIN	10
 
 #define AO_ADC_SENSE_DROGUE	4
 #define AO_ADC_SENSE_DROGUE_PORT	(&stm_gpioa)
@@ -296,11 +323,11 @@ struct ao_adc {
 
 #define M25_MAX_CHIPS		1
 #define AO_M25_SPI_CS_PORT	(&stm_gpiod)
-#define AO_M25_SPI_CS_MASK	(1 << 3)
+#define AO_M25_SPI_CS_MASK	(1 << 10)
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * Radio (cc1120)
+ * Radio (cc1200)
  */
 
 /* gets pretty close to 434.550 */
@@ -313,10 +340,8 @@ struct ao_adc {
 #define AO_CC1200_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
 #define AO_CC1200_SPI		stm_spi2
 
-#define AO_CC1200_INT_PORT		(&stm_gpioe)
-#define AO_CC1200_INT_PIN		1
-#define AO_CC1200_MCU_WAKEUP_PORT	(&stm_gpioc)
-#define AO_CC1200_MCU_WAKEUP_PIN	(0)
+#define AO_CC1200_INT_PORT		(&stm_gpiob)
+#define AO_CC1200_INT_PIN		11
 
 #define AO_CC1200_INT_GPIO	2
 #define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
@@ -326,36 +351,103 @@ struct ao_adc {
 
 #define HAS_BOOT_RADIO		0
 
+
 /*
- * bmx160
+ *
+ * Here are the required sensor signs:
+ *
+ * +along	nose up
+ * +across 	USB down
+ * +through	TH down
+ *
+ * With the board aligned to have positive accel for the relevant
+ * axis, looking down from above we have:
+ *
+ * +roll	counter clockwise (nose up)
+ * +pitch	counter clockwise (USB down)
+ * +yaw		counter clockwise (TH down)
  */
 
-#define HAS_BMX160		1
-#define AO_BMX160_INT_PORT	(&stm_gpioe)
-#define AO_BMX160_INT_PIN	0
-#define AO_BMX160_SPI_BUS	AO_SPI_1_PE13_PE14_PE15
-#define AO_BMX160_SPI_CS_PORT	(&stm_gpiod)
-#define AO_BMX160_SPI_CS_PIN	2
+/*
+ * On TMega v6, bmi088 pin 1 (NE corner of chip) is placed towards the
+ * USB and antenna edges of the board. Relative to bmi088 specs, to
+ * get the above values, we need to flip the Y axis, assigning values
+ * as follows:
+ *
+ *	+along		+X	+roll	+X
+ *	+across		-Y	+pitch	-Y
+ *	+through	+Z	+yaw	+Z
+ */
+
+#define HAS_BMI088		1
+#define AO_BMI088_SPI_BUS	AO_SPI_1_PE13_PE14_PE15
+#define AO_BMI088_ACC_CS_PORT	(&stm_gpioc)
+#define AO_BMI088_ACC_CS_PIN	14
+#define AO_BMI088_GYR_CS_PORT	(&stm_gpioc)
+#define AO_BMI088_GYR_CS_PIN	13
 #define HAS_IMU			1
 
-#define ao_data_along(packet)	((packet)->bmx160.acc_x)
-#define ao_data_across(packet)	(-(packet)->bmx160.acc_y)
-#define ao_data_through(packet)	((packet)->bmx160.acc_z)
+#define ao_bmi088_along(m)	((m)->acc.x)
+#define ao_bmi088_across(m)	(-(m)->acc.y)
+#define ao_bmi088_through(m)	((m)->acc.z)
 
-#define ao_data_roll(packet)	((packet)->bmx160.gyr_x)
-#define ao_data_pitch(packet)	(-(packet)->bmx160.gyr_y)
-#define ao_data_yaw(packet)	((packet)->bmx160.gyr_z)
+#define ao_bmi088_roll(m)	((m)->gyr.x)
+#define ao_bmi088_pitch(m)	(-(m)->gyr.y)
+#define ao_bmi088_yaw(m)	((m)->gyr.z)
 
-#define ao_data_mag_along(packet)	((packet)->bmx160.mag_x)
-#define ao_data_mag_across(packet)	((packet)->bmx160.mag_y)
-#define ao_data_mag_through(packet)	((packet)->bmx160.mag_z)
+#define ao_data_along(packet)	ao_bmi088_along(&(packet)->bmi088)
+#define ao_data_across(packet)	ao_bmi088_across(&(packet)->bmi088)
+#define ao_data_through(packet)	ao_bmi088_through(&(packet)->bmi088)
 
-/* ADXL375 */
+#define ao_data_roll(packet)	ao_bmi088_roll(&(packet)->bmi088)
+#define ao_data_pitch(packet)	ao_bmi088_pitch(&(packet)->bmi088)
+#define ao_data_yaw(packet)	ao_bmi088_yaw(&(packet)->bmi088)
+
+/*
+ * MMC5983
+ *
+ *	pin 1 NE corner of chip
+ *
+ *	+along		-Y
+ *	+across		+X
+ *	+through	-Z
+ */
+
+#define HAS_MMC5983		1
+#define AO_MMC5983_INT_PORT	(&stm_gpiod)
+#define AO_MMC5983_INT_PIN	5
+#define AO_MMC5983_SPI_CLK_PORT	(&stm_gpiod)
+#define AO_MMC5983_SPI_CLK_PIN	1
+#define AO_MMC5983_SPI_MISO_PORT	(&stm_gpiod)
+#define AO_MMC5983_SPI_MISO_PIN	3
+#define AO_MMC5983_SPI_MOSI_PORT	(&stm_gpiod)
+#define AO_MMC5983_SPI_MOSI_PIN	4
+#define AO_MMC5983_SPI_INDEX	(AO_SPI_2_PD1_PD3_PD4 | AO_SPI_MODE_3)
+#define AO_MMC5983_SPI_CS_PORT	(&stm_gpioa)
+#define AO_MMC5983_SPI_CS_PIN	15
+
+#define ao_mmc5983_along(m)		(-(m)->y)
+#define ao_mmc5983_across(m)		((m)->x)
+#define ao_mmc5983_through(m)		(-(m)->z)
+
+#define ao_data_mag_along(packet)	ao_mmc5983_along(&(packet)->mmc5983)
+#define ao_data_mag_across(packet)	ao_mmc5983_across(&(packet)->mmc5983)
+#define ao_data_mag_through(packet)	ao_mmc5983_through(&(packet)->mmc5983)
+
+/*
+ * ADXL375
+ *
+ * pin 1 NW corner of chip
+ *
+ *	+along		+X
+ *	+across		+Y
+ *	+through	+Z
+ */
 
 #define HAS_ADXL375		1
 #define AO_ADXL375_SPI_INDEX	(AO_SPI_1_PB3_PB4_PB5 | AO_SPI_MODE_3)
-#define AO_ADXL375_CS_PORT	(&stm_gpiod)
-#define AO_ADXL375_CS_PIN	4
+#define AO_ADXL375_CS_PORT	(&stm_gpioc)
+#define AO_ADXL375_CS_PIN	0
 
 #define AO_ADXL375_AXIS		x
 #define AO_ADXL375_INVERT	1
@@ -407,9 +499,9 @@ struct ao_adc {
 #define AO_PWM_1_PIN		13
 
 #define AO_PWM_2_GPIO		(&stm_gpiod)
-#define AO_PWM_2_PIN		14
+#define AO_PWM_2_PIN		15
 
 #define AO_PWM_3_GPIO		(&stm_gpiod)
-#define AO_PWM_3_PIN		15
+#define AO_PWM_3_PIN		14
 
 #endif /* _AO_PINS_H_ */
