@@ -248,42 +248,43 @@ struct ao_adc {
 #define AO_M25_SPI_BUS		AO_SPI_2_PB13_PB14_PB15
 
 /*
- * Radio (cc1200)
+ * Radio (cc1120)
  */
 
 /* gets pretty close to 434.550 */
 
-#define AO_RADIO_CAL_DEFAULT 	5695733
+#define AO_RADIO_CAL_DEFAULT 	0x6ca333
 
-#define AO_CC1200_SPI_CS_PORT	(&stm_gpioa)
-#define AO_CC1200_SPI_CS_PIN	2
-#define AO_CC1200_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
-#define AO_CC1200_SPI		stm_spi2
+#define AO_FEC_DEBUG		0
+#define AO_CC1120_SPI_CS_PORT	(&stm_gpioa)
+#define AO_CC1120_SPI_CS_PIN	2
+#define AO_CC1120_SPI_BUS	AO_SPI_2_PB13_PB14_PB15
+#define AO_CC1120_SPI		stm_spi2
 
-#define AO_CC1200_INT_PORT		(&stm_gpioa)
-#define AO_CC1200_INT_PIN		(3)
-#define AO_CC1200_MCU_WAKEUP_PORT	(&stm_gpioa)
-#define AO_CC1200_MCU_WAKEUP_PIN	(4)
+#define AO_CC1120_INT_PORT		(&stm_gpioa)
+#define AO_CC1120_INT_PIN		(3)
+#define AO_CC1120_MCU_WAKEUP_PORT	(&stm_gpioa)
+#define AO_CC1120_MCU_WAKEUP_PIN	(4)
 
-#define AO_CC1200_INT_GPIO	2
-#define AO_CC1200_INT_GPIO_IOCFG	CC1200_IOCFG2
+#define AO_CC1120_INT_GPIO	2
+#define AO_CC1120_INT_GPIO_IOCFG	CC1120_IOCFG2
 
-#define AO_CC1200_MARC_GPIO	3
-#define AO_CC1200_MARC_GPIO_IOCFG	CC1200_IOCFG3
+#define AO_CC1120_MARC_GPIO	3
+#define AO_CC1120_MARC_GPIO_IOCFG	CC1120_IOCFG3
 
 #define HAS_BOOT_RADIO		0
 
 #define HAS_HIGHG_ACCEL		1
 
-/* ADXL375 */
+/*
+ * mma655x
+ */
 
-#define HAS_ADXL375		1
-#define AO_ADXL375_SPI_INDEX	(AO_SPI_1_PB3_PB4_PB5 | AO_SPI_MODE_3)
-#define AO_ADXL375_CS_PORT	(&stm_gpiob)
-#define AO_ADXL375_CS_PIN	9
-
-#define AO_ADXL375_AXIS		x
-#define AO_ADXL375_INVERT	1
+#define HAS_MMA655X		1
+#define AO_MMA655X_SPI_INDEX	AO_SPI_1_PB3_PB4_PB5
+#define AO_MMA655X_CS_PORT	(&stm_gpiob)
+#define AO_MMA655X_CS_PIN	9
+#define AO_MMA655X_INVERT	1
 
 #define NUM_CMDS		16
 
